@@ -3,17 +3,20 @@
 use strict;
 use warnings;
 
+# VERSION
+
 use lib qw(../lib  lib);
 
 use POE qw(Component::IRC Component::IRC::Plugin::CPAN::Info);
 
 my @Channels = ( '#zofbot' );
 
-my $irc = POE::Component::IRC->spawn( 
+my $irc = POE::Component::IRC->spawn(
         nick    => 'CPANInfoBot',
         server  => 'irc.freenode.net',
         port    => 6667,
         ircname => 'CPAN module information bot',
+        debug => 1,
 ) or die "Oh noes :( $!";
 
 POE::Session->create(
@@ -32,13 +35,13 @@ $poe_kernel->run();
 
 sub _start {
     $irc->yield( register => 'all' );
-    
+
     # register our plugin
     $irc->plugin_add(
-        'CPANInfo' => 
-            POE::Component::IRC::Plugin::CPAN::Info->new
+        'CPANInfo' =>
+            POE::Component::IRC::Plugin::CPAN::Info->new( debug => 1 )
     );
-    
+
     $irc->yield( connect => { } );
     undef;
 }
